@@ -1,5 +1,5 @@
 package Pithub;
-$Pithub::VERSION = '0.01022';
+$Pithub::VERSION = '0.01023';
 # ABSTRACT: Github v3 API
 
 use Moo;
@@ -75,7 +75,7 @@ Pithub - Github v3 API
 
 =head1 VERSION
 
-version 0.01022
+version 0.01023
 
 =head1 SYNOPSIS
 
@@ -482,6 +482,10 @@ See also: L<http://developer.github.com/v3/repos/contents/>
 
 L<Pithub::Repos::Downloads>
 
+Github says: The Downloads API (described below) was deprecated on
+December 11, 2012. It will be removed at a future date. We recommend
+using L<Pithub::Repos::Releases> instead.
+
 See also: L<http://developer.github.com/v3/repos/downloads/>
 
     my $downloads = Pithub->new->repos->downloads;
@@ -510,6 +514,31 @@ See also: L<http://developer.github.com/v3/repos/keys/>
 
 =item *
 
+L<Pithub::Repos::Releases>
+
+See also: L<http://developer.github.com/v3/repos/releases/>
+
+    my $releases = Pithub->new->repos->releases;
+    my $releases = Pithub::Repos->new->releases;
+    my $releases = Pithub::Repos::Releases->new;
+
+=over
+
+=item *
+
+L<Pithub::Repos::Releases::Assets>
+
+See also: L<http://developer.github.com/v3/repos/releases/>
+
+    my $assets = Pithub->new->repos->releases->assets;
+    my $assets = Pithub::Repos->new->releases->assets;
+    my $assets = Pithub::Repos::Releases->new->assets;
+    my $assets = Pithub::Repos::Releases::Assets->new;
+
+=back
+
+=item *
+
 L<Pithub::Repos::Stats>
 
 See also: L<http://developer.github.com/v3/repos/statistics/>
